=====================
Implemented Standards
=====================

Present
=======

- ``dNSName`` with fallback to ``CN`` (DNS-ID, aka host names, `RFC 6125`_).
- ``uniformResourceIdentifier`` (URI-ID, `RFC 6125`_).
- SRV-ID (`RFC 6125`_)


Future
======

- ``xmppAddr`` (`RFC 3920`_).
- ``iPAddress`` (`RFC 2818`_).
- ``nameConstraints`` extensions (`RFC 3280`_).

.. _`RFC 2818`: https://tools.ietf.org/search/rfc2818
.. _`RFC 3280`: https://tools.ietf.org/search/rfc3280#section-4.2.1.11
.. _`RFC 3920`: https://tools.ietf.org/search/rfc3920
.. _`RFC 6125`: https://tools.ietf.org/search/rfc6125
